@@ -19,16 +19,23 @@
 
 
 #if defined(ARMA_RNG_ALT)
-  #undef ARMA_USE_EXTERN_CXX11_RNG
+  #undef ARMA_USE_EXTERN_RNG
 #endif
 
 
-#if !defined(ARMA_USE_CXX11)
-  #undef ARMA_USE_EXTERN_CXX11_RNG
+// workaround for issue on macOS 11 and/or AppleClang 12.0
+// see https://gitlab.com/conradsnicta/armadillo-code/-/issues/173
+// the workaround is here instead of CMakeLists.txt
+// to ensure that the armadillo runtime library has arma_rng_cxx11_instance
+// for already compiled programs running on earlier versions of macOS
+#if defined(__APPLE__) || defined(__apple_build_version__)
+  #if !defined(ARMA_DONT_DISABLE_EXTERN_RNG)
+    #undef ARMA_USE_EXTERN_RNG
+  #endif
 #endif
 
 
-#if defined(ARMA_USE_EXTERN_CXX11_RNG)
+#if defined(ARMA_USE_EXTERN_RNG)
   extern thread_local arma_rng_cxx11 arma_rng_cxx11_instance;
   // namespace { thread_local arma_rng_cxx11 arma_rng_cxx11_instance; }
 #endif
@@ -40,18 +47,18 @@ class arma_rng
   
   #if   defined(ARMA_RNG_ALT)
     typedef arma_rng_alt::seed_type   seed_type;
-  #elif defined(ARMA_USE_EXTERN_CXX11_RNG)
+  #elif defined(ARMA_USE_EXTERN_RNG)
     typedef arma_rng_cxx11::seed_type seed_type;
   #else
     typedef arma_rng_cxx98::seed_type seed_type;
   #endif
   
   #if   defined(ARMA_RNG_ALT)
-    static const int rng_method = 2;
-  #elif defined(ARMA_USE_EXTERN_CXX11_RNG)
-    static const int rng_method = 1;
+    static constexpr int rng_method = 2;
+  #elif defined(ARMA_USE_EXTERN_RNG)
+    static constexpr int rng_method = 1;
   #else
-    static const int rng_method = 0;
+    static constexpr int rng_method = 0;
   #endif
   
   inline static void set_seed(const seed_type val);
@@ -72,7 +79,7 @@ arma_rng::set_seed(const arma_rng::seed_type val)
     {
     arma_rng_alt::set_seed(val);
     }
-  #elif defined(ARMA_USE_EXTERN_CXX11_RNG)
+  #elif defined(ARMA_USE_EXTERN_RNG)
     {
     arma_rng_cxx11_instance.set_seed(val);
     }
@@ -94,23 +101,18 @@ arma_rng::set_seed_random()
   seed_type seed2 = seed_type(0);
   seed_type seed3 = seed_type(0);
   seed_type seed4 = seed_type(0);
-  seed_type seed5 = seed_type(0);
   
   bool have_seed = false;
   
-  #if defined(ARMA_USE_CXX11)
+  try
     {
-    try
-      {
-      std::random_device rd;
-      
-      if(rd.entropy() > double(0))  { seed1 = static_cast<seed_type>( rd() ); }
-      
-      if(seed1 != seed_type(0))  { have_seed = true; }
-      }
-    catch(...) {}
+    std::random_device rd;
+    
+    if(rd.entropy() > double(0))  { seed1 = static_cast<seed_type>( rd() ); }
+    
+    if(seed1 != seed_type(0))  { have_seed = true; }
     }
-  #endif
+  catch(...) {}
   
   
   if(have_seed == false)
@@ -144,17 +146,11 @@ arma_rng::set_seed_random()
     {
     // get better-than-nothing seeds in case reading /dev/urandom failed 
     
-    #if defined(ARMA_HAVE_GETTIMEOFDAY)
-      {
-      struct timeval posix_time;
-      
-      gettimeofday(&posix_time, 0);
-      
-      seed3 = static_cast<seed_type>(posix_time.tv_usec);
-      }
-    #endif
+    const std::chrono::system_clock::time_point tp_now = std::chrono::system_clock::now();
     
-    seed4 = static_cast<seed_type>( std::time(NULL) & 0xFFFF );
+    auto since_epoch_usec = std::chrono::duration_cast<std::chrono::microseconds>(tp_now.time_since_epoch()).count();
+    
+    seed3 = static_cast<seed_type>( since_epoch_usec & 0xFFFF );
     
     union
       {
@@ -164,15 +160,15 @@ arma_rng::set_seed_random()
     
     tmp.a = (uword*)malloc(sizeof(uword));
     
-    if(tmp.a != NULL)
+    if(tmp.a != nullptr)
       {
-      for(size_t i=0; i<sizeof(uword*); ++i)  { seed5 += seed_type(tmp.b[i]); }
+      for(size_t i=0; i<sizeof(uword*); ++i)  { seed4 += seed_type(tmp.b[i]); }
       
       free(tmp.a);
       }
     }
   
-  arma_rng::set_seed( seed1 + seed2 + seed3 + seed4 + seed5 );
+  arma_rng::set_seed( seed1 + seed2 + seed3 + seed4 );
   }
 
 
@@ -187,7 +183,7 @@ struct arma_rng::randi
       {
       return eT( arma_rng_alt::randi_val() );
       }
-    #elif defined(ARMA_USE_EXTERN_CXX11_RNG)
+    #elif defined(ARMA_USE_EXTERN_RNG)
       {
       return eT( arma_rng_cxx11_instance.randi_val() );
       }
@@ -208,7 +204,7 @@ struct arma_rng::randi
       {
       return arma_rng_alt::randi_max_val();
       }
-    #elif defined(ARMA_USE_EXTERN_CXX11_RNG)
+    #elif defined(ARMA_USE_EXTERN_RNG)
       {
       return arma_rng_cxx11::randi_max_val();
       }
@@ -229,13 +225,22 @@ struct arma_rng::randi
       {
       arma_rng_alt::randi_fill(mem, N, a, b);
       }
-    #elif defined(ARMA_USE_EXTERN_CXX11_RNG)
+    #elif defined(ARMA_USE_EXTERN_RNG)
       {
       arma_rng_cxx11_instance.randi_fill(mem, N, a, b);
       }
     #else
       {
-      arma_rng_cxx98::randi_fill(mem, N, a, b);
+      if(N == uword(1))  { arma_rng_cxx98::randi_fill(mem, uword(1), a, b); return; }
+      
+      typedef typename std::mt19937_64::result_type seed_type;
+      
+      std::mt19937_64                    local_engine;
+      std::uniform_int_distribution<int> local_i_distr(a, b);
+      
+      local_engine.seed( seed_type(std::rand()) );
+      
+      for(uword i=0; i<N; ++i)  { mem[i] = eT(local_i_distr(local_engine)); }
       }
     #endif
     }
@@ -253,7 +258,7 @@ struct arma_rng::randu
       {
       return eT( arma_rng_alt::randu_val() );
       }
-    #elif defined(ARMA_USE_EXTERN_CXX11_RNG)
+    #elif defined(ARMA_USE_EXTERN_RNG)
       {
       return eT( arma_rng_cxx11_instance.randu_val() );
       }
@@ -270,21 +275,24 @@ struct arma_rng::randu
   void
   fill(eT* mem, const uword N)
     {
-    uword j;
-    
-    for(j=1; j < N; j+=2)
+    #if defined(ARMA_RNG_ALT) || defined(ARMA_USE_EXTERN_RNG)
       {
-      const eT tmp_i = eT( arma_rng::randu<eT>() );
-      const eT tmp_j = eT( arma_rng::randu<eT>() );
+      for(uword i=0; i < N; ++i)  { mem[i] = eT( arma_rng::randu<eT>() ); }
+      }
+    #else
+      {
+      if(N == uword(1))  { mem[0] = eT( arma_rng_cxx98::randu_val() ); return; }
       
-      (*mem) = tmp_i;  mem++;
-      (*mem) = tmp_j;  mem++;
-      }
-    
-    if((j-1) < N)
-      {
-      (*mem) = eT( arma_rng::randu<eT>() );
+      typedef typename std::mt19937_64::result_type seed_type;
+      
+      std::mt19937_64                        local_engine;
+      std::uniform_real_distribution<double> local_u_distr;
+      
+      local_engine.seed( seed_type(std::rand()) );
+      
+      for(uword i=0; i < N; ++i)  { mem[i] = eT( local_u_distr(local_engine) ); }
       }
+    #endif
     }
   };
 
@@ -308,13 +316,44 @@ struct arma_rng::randu< std::complex<T> >
   void
   fill(std::complex<T>* mem, const uword N)
     {
-    for(uword i=0; i < N; ++i)
+    #if defined(ARMA_RNG_ALT) || defined(ARMA_USE_EXTERN_RNG)
       {
-      const T a = T( arma_rng::randu<T>() );
-      const T b = T( arma_rng::randu<T>() );
-      
-      mem[i] = std::complex<T>(a, b);
+      for(uword i=0; i < N; ++i)
+        {
+        const T a = T( arma_rng::randu<T>() );
+        const T b = T( arma_rng::randu<T>() );
+        
+        mem[i] = std::complex<T>(a, b);
+        }
       }
+    #else
+      {
+      if(N == uword(1))
+        {
+        const T a = T( arma_rng_cxx98::randu_val() );
+        const T b = T( arma_rng_cxx98::randu_val() );
+        
+        mem[0] = std::complex<T>(a, b);
+        
+        return;
+        }
+      
+      typedef typename std::mt19937_64::result_type seed_type;
+      
+      std::mt19937_64                        local_engine;
+      std::uniform_real_distribution<double> local_u_distr;
+      
+      local_engine.seed( seed_type(std::rand()) );
+      
+      for(uword i=0; i < N; ++i)
+        {
+        const T a = T( local_u_distr(local_engine) );
+        const T b = T( local_u_distr(local_engine) );
+        
+        mem[i] = std::complex<T>(a, b);
+        }
+      }
+    #endif
     }
   };
 
@@ -330,7 +369,7 @@ struct arma_rng::randn
       {
       return eT( arma_rng_alt::randn_val() );
       }
-    #elif defined(ARMA_USE_EXTERN_CXX11_RNG)
+    #elif defined(ARMA_USE_EXTERN_RNG)
       {
       return eT( arma_rng_cxx11_instance.randn_val() );
       }
@@ -342,7 +381,7 @@ struct arma_rng::randn
     }
   
   
-  arma_inline
+  inline
   static
   void
   dual_val(eT& out1, eT& out2)
@@ -351,7 +390,7 @@ struct arma_rng::randn
       {
       arma_rng_alt::randn_dual_val(out1, out2);
       }
-    #elif defined(ARMA_USE_EXTERN_CXX11_RNG)
+    #elif defined(ARMA_USE_EXTERN_RNG)
       {
       arma_rng_cxx11_instance.randn_dual_val(out1, out2);
       }
@@ -368,17 +407,34 @@ struct arma_rng::randn
   void
   fill_simple(eT* mem, const uword N)
     {
-    uword i, j;
-    
-    for(i=0, j=1; j < N; i+=2, j+=2)
+    #if defined(ARMA_RNG_ALT) || defined(ARMA_USE_EXTERN_RNG)
       {
-      arma_rng::randn<eT>::dual_val( mem[i], mem[j] );
+      uword i, j;
+      
+      for(i=0, j=1; j < N; i+=2, j+=2)
+        {
+        arma_rng::randn<eT>::dual_val( mem[i], mem[j] );
+        }
+      
+      if(i < N)
+        {
+        mem[i] = eT( arma_rng::randn<eT>() );
+        }
       }
-    
-    if(i < N)
+    #else
       {
-      mem[i] = eT( arma_rng::randn<eT>() );
+      if(N == uword(1))  { mem[0] = eT( arma_rng_cxx98::randn_val() ); return; }
+      
+      typedef typename std::mt19937_64::result_type seed_type;
+      
+      std::mt19937_64                  local_engine;
+      std::normal_distribution<double> local_n_distr;
+      
+      local_engine.seed( seed_type(std::rand()) );
+      
+      for(uword i=0; i < N; ++i)  { mem[i] = eT( local_n_distr(local_engine) ); }
       }
+    #endif
     }
   
   
@@ -387,11 +443,11 @@ struct arma_rng::randn
   void
   fill(eT* mem, const uword N)
     {
-    #if defined(ARMA_USE_CXX11) && defined(ARMA_USE_OPENMP)
+    #if defined(ARMA_USE_OPENMP)
       {
       if((N < 1024) || omp_in_parallel())  { arma_rng::randn<eT>::fill_simple(mem, N); return; }
       
-      typedef std::mt19937_64::result_type seed_type;
+      typedef typename std::mt19937_64::result_type seed_type;
       
       const uword n_threads = uword( mp_thread_limit::get() );
       
@@ -441,8 +497,15 @@ struct arma_rng::randn< std::complex<T> >
   inline
   operator std::complex<T> () const
     {
-    T a;
-    T b;
+    #if defined(_MSC_VER)
+      // attempt at workaround for MSVC bug
+      // does MS even test their so-called compilers before release?
+      T a;
+      T b;
+    #else
+      T a(0);
+      T b(0);
+    #endif
     
     arma_rng::randn<T>::dual_val(a, b);
     
@@ -450,15 +513,66 @@ struct arma_rng::randn< std::complex<T> >
     }
   
   
+  inline
+  static
+  void
+  dual_val(std::complex<T>& out1, std::complex<T>& out2)
+    {
+    #if defined(_MSC_VER)
+      T a;
+      T b;
+    #else
+      T a(0);
+      T b(0);
+    #endif
+    
+    arma_rng::randn<T>::dual_val(a,b);
+    out1 = std::complex<T>(a,b);
+    
+    arma_rng::randn<T>::dual_val(a,b);
+    out2 = std::complex<T>(a,b);
+    }
+  
+  
   inline
   static
   void
   fill_simple(std::complex<T>* mem, const uword N)
     {
-    for(uword i=0; i < N; ++i)
+    #if defined(ARMA_RNG_ALT) || defined(ARMA_USE_EXTERN_RNG)
       {
-      mem[i] = std::complex<T>( arma_rng::randn< std::complex<T> >() );
+      for(uword i=0; i < N; ++i)  { mem[i] = std::complex<T>( arma_rng::randn< std::complex<T> >() ); }
       }
+    #else
+      {
+      if(N == uword(1))
+        {
+        T a = T(0);
+        T b = T(0);
+        
+        arma_rng_cxx98::randn_dual_val(a,b);
+        
+        mem[0] = std::complex<T>(a,b);
+        
+        return;
+        }
+      
+      typedef typename std::mt19937_64::result_type seed_type;
+      
+      std::mt19937_64                  local_engine;
+      std::normal_distribution<double> local_n_distr;
+      
+      local_engine.seed( seed_type(std::rand()) );
+      
+      for(uword i=0; i < N; ++i)
+        {
+        const T a = T( local_n_distr(local_engine) );
+        const T b = T( local_n_distr(local_engine) );
+        
+        mem[i] = std::complex<T>(a,b);
+        }
+      }
+    #endif
     }
   
   
@@ -467,11 +581,11 @@ struct arma_rng::randn< std::complex<T> >
   void
   fill(std::complex<T>* mem, const uword N)
     {
-    #if defined(ARMA_USE_CXX11) && defined(ARMA_USE_OPENMP)
+    #if defined(ARMA_USE_OPENMP)
       {
       if((N < 512) || omp_in_parallel())  { arma_rng::randn< std::complex<T> >::fill_simple(mem, N); return; }
       
-      typedef std::mt19937_64::result_type seed_type;
+      typedef typename std::mt19937_64::result_type seed_type;
       
       const uword n_threads = uword( mp_thread_limit::get() );
       
