@@ -146,6 +146,25 @@ arma_stop_logic_error(const T1& x)
 
 
 
+//! print a message to get_cerr_stream() and throw logic_error exception
+template<typename T1>
+arma_cold
+arma_noinline
+static
+void
+arma_stop_bounds_error(const T1& x)
+  {
+  #if defined(ARMA_PRINT_ERRORS)
+    {
+    get_cerr_stream() << "\nerror: " << x << std::endl;
+    }
+  #endif
+  
+  throw std::out_of_range( std::string(x) );
+  }
+
+
+
 //! print a message to get_cerr_stream() and throw bad_alloc exception
 template<typename T1>
 arma_cold
@@ -313,15 +332,15 @@ arma_cold
 arma_noinline
 static
 void
-arma_warn(const T1& x)
+arma_warn(const T1& arg1)
   {
   #if defined(ARMA_PRINT_ERRORS)
     {
-    get_cerr_stream() << "\nwarning: " << x << '\n';
+    get_cerr_stream() << "\nwarning: " << arg1 << '\n';
     }
   #else
     {
-    arma_ignore(x);
+    arma_ignore(arg1);
     }
   #endif
   }
@@ -332,16 +351,16 @@ arma_cold
 arma_noinline
 static
 void
-arma_warn(const T1& x, const T2& y)
+arma_warn(const T1& arg1, const T2& arg2)
   {
   #if defined(ARMA_PRINT_ERRORS)
     {
-    get_cerr_stream() << "\nwarning: " << x << y << '\n';
+    get_cerr_stream() << "\nwarning: " << arg1 << arg2 << '\n';
     }
   #else
     {
-    arma_ignore(x);
-    arma_ignore(y);
+    arma_ignore(arg1);
+    arma_ignore(arg2);
     }
   #endif
   }
@@ -352,17 +371,39 @@ arma_cold
 arma_noinline
 static
 void
-arma_warn(const T1& x, const T2& y, const T3& z)
+arma_warn(const T1& arg1, const T2& arg2, const T3& arg3)
   {
   #if defined(ARMA_PRINT_ERRORS)
     {
-    get_cerr_stream() << "\nwarning: " << x << y << z << '\n';
+    get_cerr_stream() << "\nwarning: " << arg1 << arg2 << arg3 << '\n';
     }
   #else
     {
-    arma_ignore(x);
-    arma_ignore(y);
-    arma_ignore(z);
+    arma_ignore(arg1);
+    arma_ignore(arg2);
+    arma_ignore(arg3);
+    }
+  #endif
+  }
+
+
+template<typename T1, typename T2, typename T3, typename T4>
+arma_cold
+arma_noinline
+static
+void
+arma_warn(const T1& arg1, const T2& arg2, const T3& arg3, const T4& arg4)
+  {
+  #if defined(ARMA_PRINT_ERRORS)
+    {
+    get_cerr_stream() << "\nwarning: " << arg1 << arg2 << arg3 << arg4 << '\n';
+    }
+  #else
+    {
+    arma_ignore(arg1);
+    arma_ignore(arg2);
+    arma_ignore(arg3);
+    arma_ignore(arg4);
     }
   #endif
   }
@@ -393,6 +434,16 @@ arma_check(const bool state, const T1& x, const T2& y)
   }
 
 
+template<typename T1>
+arma_hot
+inline
+void
+arma_check_bounds(const bool state, const T1& x)
+  {
+  if(state)  { arma_stop_bounds_error(arma_str::str_wrapper(x)); }
+  }
+
+
 template<typename T1>
 arma_hot
 inline
@@ -780,6 +831,28 @@ arma_assert_same_size(const subview_cube<eT1>& A, const subview_cube<eT2>& B, co
 
 
 
+template<typename eT, typename T1>
+arma_hot
+inline
+void
+arma_assert_same_size(const subview_cube<eT>& A, const ProxyCube<T1>& B, const char* x)
+  {
+  const uword A_n_rows   = A.n_rows;
+  const uword A_n_cols   = A.n_cols;
+  const uword A_n_slices = A.n_slices;
+  
+  const uword B_n_rows   = B.get_n_rows();
+  const uword B_n_cols   = B.get_n_cols();
+  const uword B_n_slices = B.get_n_slices();
+  
+  if( (A_n_rows != B_n_rows) || (A_n_cols != B_n_cols) || (A_n_slices != B_n_slices) )
+    {
+    arma_stop_logic_error( arma_incompat_size_string(A_n_rows, A_n_cols, A_n_slices, B_n_rows, B_n_cols, B_n_slices, x) );
+    }
+  }
+
+
+
 //! stop if given cube proxies have different sizes
 template<typename eT1, typename eT2>
 arma_hot
@@ -1241,6 +1314,7 @@ arma_assert_atlas_size(const T1& A, const T2& B)
   #define arma_debug_print                   true ? (void)0 : arma_print
   #define arma_debug_warn                    true ? (void)0 : arma_warn
   #define arma_debug_check                   true ? (void)0 : arma_check
+  #define arma_debug_check_bounds            true ? (void)0 : arma_check_bounds
   #define arma_debug_set_error               true ? (void)0 : arma_set_error
   #define arma_debug_assert_same_size        true ? (void)0 : arma_assert_same_size
   #define arma_debug_assert_mul_size         true ? (void)0 : arma_assert_mul_size
@@ -1254,6 +1328,7 @@ arma_assert_atlas_size(const T1& A, const T2& B)
   #define arma_debug_print                 arma_print
   #define arma_debug_warn                  arma_warn
   #define arma_debug_check                 arma_check
+  #define arma_debug_check_bounds          arma_check_bounds
   #define arma_debug_set_error             arma_set_error
   #define arma_debug_assert_same_size      arma_assert_same_size
   #define arma_debug_assert_mul_size       arma_assert_mul_size
