@@ -74,6 +74,7 @@ field<oT>::operator=(const field& x)
   arma_extra_debug_sigprint();
   
   init(x);
+  
   return *this;
   }
 
@@ -105,6 +106,7 @@ field<oT>::operator=(const subview_field<oT>& X)
   arma_extra_debug_sigprint();
   
   subview_field<oT>::extract(*this, X);
+  
   return *this;
   }
 
@@ -280,10 +282,7 @@ field<oT>::operator=(const std::vector<oT>& x)
   
   set_size(N, 1);
   
-  for(uword i=0; i<N; ++i)
-    {
-    operator[](i) = x[i];
-    }
+  for(uword i=0; i<N; ++i)  { operator[](i) = x[i]; }
   
   return *this;
   }
@@ -318,10 +317,7 @@ field<oT>::operator=(const std::initializer_list<oT>& list)
   
   const oT* item_ptr = list.begin();
   
-  for(uword i=0; i<N; ++i)
-    {
-    operator[](i) = item_ptr[i];
-    }
+  for(uword i=0; i<N; ++i)  { operator[](i) = item_ptr[i]; }
   
   return *this;
   }
@@ -356,10 +352,7 @@ field<oT>::operator=(const std::initializer_list< std::initializer_list<oT> >& l
   auto it     = list.begin();
   auto it_end = list.end();
   
-  for(; it != it_end; ++it)
-    {
-    x_n_cols = (std::max)(x_n_cols, uword((*it).size()));
-    }
+  for(; it != it_end; ++it)  { x_n_cols = (std::max)(x_n_cols, uword((*it).size())); }
   
   field<oT>& t = (*this);
   
@@ -524,7 +517,8 @@ arma_inline
 oT&
 field<oT>::operator() (const uword i)
   {
-  arma_debug_check( (i >= n_elem), "field::operator(): index out of bounds" );
+  arma_debug_check_bounds( (i >= n_elem), "field::operator(): index out of bounds" );
+  
   return (*mem[i]);
   }
 
@@ -536,7 +530,8 @@ arma_inline
 const oT&
 field<oT>::operator() (const uword i) const
   {
-  arma_debug_check( (i >= n_elem), "field::operator(): index out of bounds" );
+  arma_debug_check_bounds( (i >= n_elem), "field::operator(): index out of bounds" );
+  
   return (*mem[i]);
   }
 
@@ -548,7 +543,8 @@ arma_inline
 oT&
 field<oT>::operator() (const uword in_row, const uword in_col)
   {
-  arma_debug_check( ((in_row >= n_rows) || (in_col >= n_cols) || (0 >= n_slices) ), "field::operator(): index out of bounds" );
+  arma_debug_check_bounds( ((in_row >= n_rows) || (in_col >= n_cols) || (0 >= n_slices) ), "field::operator(): index out of bounds" );
+  
   return (*mem[in_row + in_col*n_rows]);
   }
 
@@ -560,7 +556,8 @@ arma_inline
 const oT&
 field<oT>::operator() (const uword in_row, const uword in_col) const
   {
-  arma_debug_check( ((in_row >= n_rows) || (in_col >= n_cols) || (0 >= n_slices) ), "field::operator(): index out of bounds" );
+  arma_debug_check_bounds( ((in_row >= n_rows) || (in_col >= n_cols) || (0 >= n_slices) ), "field::operator(): index out of bounds" );
+  
   return (*mem[in_row + in_col*n_rows]);
   }
 
@@ -572,7 +569,8 @@ arma_inline
 oT&
 field<oT>::operator() (const uword in_row, const uword in_col, const uword in_slice)
   {
-  arma_debug_check( ((in_row >= n_rows) || (in_col >= n_cols) || (in_slice >= n_slices)), "field::operator(): index out of bounds" );
+  arma_debug_check_bounds( ((in_row >= n_rows) || (in_col >= n_cols) || (in_slice >= n_slices)), "field::operator(): index out of bounds" );
+  
   return (*mem[in_row + in_col*n_rows + in_slice*(n_rows*n_cols)]);
   }
 
@@ -584,7 +582,8 @@ arma_inline
 const oT&
 field<oT>::operator() (const uword in_row, const uword in_col, const uword in_slice) const
   {
-  arma_debug_check( ((in_row >= n_rows) || (in_col >= n_cols) || (in_slice >= n_slices)), "field::operator(): index out of bounds" );
+  arma_debug_check_bounds( ((in_row >= n_rows) || (in_col >= n_cols) || (in_slice >= n_slices)), "field::operator(): index out of bounds" );
+  
   return (*mem[in_row + in_col*n_rows + in_slice*(n_rows*n_cols)]);
   }
 
@@ -666,7 +665,7 @@ field<oT>::row(const uword row_num)
   
   arma_debug_check( (n_slices >= 2), "field::row(): field must be 2D" );
 
-  arma_debug_check( (row_num >= n_rows), "field::row(): row out of bounds" );
+  arma_debug_check_bounds( (row_num >= n_rows), "field::row(): row out of bounds" );
   
   return subview_field<oT>(*this, row_num, 0, 1, n_cols);
   }
@@ -683,7 +682,7 @@ field<oT>::row(const uword row_num) const
   
   arma_debug_check( (n_slices >= 2), "field::row(): field must be 2D" );
 
-  arma_debug_check( (row_num >= n_rows), "field::row(): row out of bounds" );
+  arma_debug_check_bounds( (row_num >= n_rows), "field::row(): row out of bounds" );
   
   return subview_field<oT>(*this, row_num, 0, 1, n_cols);
   }
@@ -700,7 +699,7 @@ field<oT>::col(const uword col_num)
   
   arma_debug_check( (n_slices >= 2), "field::col(): field must be 2D" );
 
-  arma_debug_check( (col_num >= n_cols), "field::col(): out of bounds" );
+  arma_debug_check_bounds( (col_num >= n_cols), "field::col(): out of bounds" );
   
   return subview_field<oT>(*this, 0, col_num, n_rows, 1);
   }
@@ -717,7 +716,7 @@ field<oT>::col(const uword col_num) const
   
   arma_debug_check( (n_slices >= 2), "field::col(): field must be 2D" );
 
-  arma_debug_check( (col_num >= n_cols), "field::col(): out of bounds" );
+  arma_debug_check_bounds( (col_num >= n_cols), "field::col(): out of bounds" );
   
   return subview_field<oT>(*this, 0, col_num, n_rows, 1);
   }
@@ -732,7 +731,7 @@ field<oT>::slice(const uword slice_num)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (slice_num >= n_slices), "field::slice(): out of bounds" );
+  arma_debug_check_bounds( (slice_num >= n_slices), "field::slice(): out of bounds" );
   
   return subview_field<oT>(*this, 0, 0, slice_num, n_rows, n_cols, 1);
   }
@@ -747,7 +746,7 @@ field<oT>::slice(const uword slice_num) const
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (slice_num >= n_slices), "field::slice(): out of bounds" );
+  arma_debug_check_bounds( (slice_num >= n_slices), "field::slice(): out of bounds" );
   
   return subview_field<oT>(*this, 0, 0, slice_num, n_rows, n_cols, 1);
   }
@@ -764,7 +763,7 @@ field<oT>::rows(const uword in_row1, const uword in_row2)
   
   arma_debug_check( (n_slices >= 2), "field::rows(): field must be 2D" );
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     ( (in_row1 > in_row2) || (in_row2 >= n_rows) ),
     "field::rows(): indicies out of bounds or incorrectly used"
@@ -787,7 +786,7 @@ field<oT>::rows(const uword in_row1, const uword in_row2) const
   
   arma_debug_check( (n_slices >= 2), "field::rows(): field must be 2D" );
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     ( (in_row1 > in_row2) || (in_row2 >= n_rows) ),
     "field::rows(): indicies out of bounds or incorrectly used"
@@ -810,7 +809,7 @@ field<oT>::cols(const uword in_col1, const uword in_col2)
   
   arma_debug_check( (n_slices >= 2), "field::cols(): field must be 2D" );
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     ( (in_col1 > in_col2) || (in_col2 >= n_cols) ),
     "field::cols(): indicies out of bounds or incorrectly used"
@@ -833,7 +832,7 @@ field<oT>::cols(const uword in_col1, const uword in_col2) const
   
   arma_debug_check( (n_slices >= 2), "field::cols(): field must be 2D" );
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     ( (in_col1 > in_col2) || (in_col2 >= n_cols) ),
     "field::cols(): indicies out of bounds or incorrectly used"
@@ -854,7 +853,7 @@ field<oT>::slices(const uword in_slice1, const uword in_slice2)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     ( (in_slice1 > in_slice2) || (in_slice2 >= n_slices) ),
     "field::slices(): indicies out of bounds or incorrectly used"
@@ -875,7 +874,7 @@ field<oT>::slices(const uword in_slice1, const uword in_slice2) const
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     ( (in_slice1 > in_slice2) || (in_slice2 >= n_slices) ),
     "field::slices(): indicies out of bounds or incorrectly used"
@@ -898,7 +897,7 @@ field<oT>::subfield(const uword in_row1, const uword in_col1, const uword in_row
   
   arma_debug_check( (n_slices >= 2), "field::subfield(): field must be 2D" );
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     (in_row1 > in_row2) || (in_col1 > in_col2) || (in_row2 >= n_rows) || (in_col2 >= n_cols),
     "field::subfield(): indices out of bounds or incorrectly used"
@@ -922,7 +921,7 @@ field<oT>::subfield(const uword in_row1, const uword in_col1, const uword in_row
   
   arma_debug_check( (n_slices >= 2), "field::subfield(): field must be 2D" );
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     (in_row1 > in_row2) || (in_col1 > in_col2) || (in_row2 >= n_rows) || (in_col2 >= n_cols),
     "field::subfield(): indices out of bounds or incorrectly used"
@@ -944,7 +943,7 @@ field<oT>::subfield(const uword in_row1, const uword in_col1, const uword in_sli
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     (in_row1 > in_row2) || (in_col1 > in_col2) || (in_slice1 > in_slice2) || (in_row2 >= n_rows) || (in_col2 >= n_cols) || (in_slice2 >= n_slices),
     "field::subfield(): indices out of bounds or incorrectly used"
@@ -967,7 +966,7 @@ field<oT>::subfield(const uword in_row1, const uword in_col1, const uword in_sli
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     (in_row1 > in_row2) || (in_col1 > in_col2) || (in_slice1 > in_slice2) || (in_row2 >= n_rows) || (in_col2 >= n_cols) || (in_slice2 >= n_slices),
     "field::subfield(): indices out of bounds or incorrectly used"
@@ -998,7 +997,7 @@ field<oT>::subfield(const uword in_row1, const uword in_col1, const SizeMat& s)
   const uword s_n_rows = s.n_rows;
   const uword s_n_cols = s.n_cols;
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     ((in_row1 >= l_n_rows) || (in_col1 >= l_n_cols) || ((in_row1 + s_n_rows) > l_n_rows) || ((in_col1 + s_n_cols) > l_n_cols)),
     "field::subfield(): indices or size out of bounds"
@@ -1025,7 +1024,7 @@ field<oT>::subfield(const uword in_row1, const uword in_col1, const SizeMat& s)
   const uword s_n_rows = s.n_rows;
   const uword s_n_cols = s.n_cols;
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     ((in_row1 >= l_n_rows) || (in_col1 >= l_n_cols) || ((in_row1 + s_n_rows) > l_n_rows) || ((in_col1 + s_n_cols) > l_n_cols)),
     "field::subfield(): indices or size out of bounds"
@@ -1052,7 +1051,7 @@ field<oT>::subfield(const uword in_row1, const uword in_col1, const uword in_sli
   const uword s_n_cols     = s.n_cols;
   const uword sub_n_slices = s.n_slices;
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     ((in_row1 >= l_n_rows) || (in_col1 >= l_n_cols) || (in_slice1 >= l_n_slices) || ((in_row1 + s_n_rows) > l_n_rows) || ((in_col1 + s_n_cols) > l_n_cols) || ((in_slice1 + sub_n_slices) > l_n_slices)),
     "field::subfield(): indices or size out of bounds"
@@ -1079,7 +1078,7 @@ field<oT>::subfield(const uword in_row1, const uword in_col1, const uword in_sli
   const uword s_n_cols = s.n_cols;
   const uword sub_n_slices = s.n_slices;
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     ((in_row1 >= l_n_rows) || (in_col1 >= l_n_cols) || (in_slice1 >= l_n_slices) || ((in_row1 + s_n_rows) > l_n_rows) || ((in_col1 + s_n_cols) > l_n_cols) || ((in_slice1 + sub_n_slices) > l_n_slices)),
     "field::subfield(): indices or size out of bounds"
@@ -1114,7 +1113,7 @@ field<oT>::subfield(const span& row_span, const span& col_span)
   const uword in_col2    =                          col_span.b;
   const uword sub_n_cols = col_all ? local_n_cols : in_col2 - in_col1 + 1;
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     ( row_all ? false : ((in_row1 > in_row2) || (in_row2 >= local_n_rows)) )
     ||
@@ -1152,7 +1151,7 @@ field<oT>::subfield(const span& row_span, const span& col_span) const
   const uword in_col2    =                          col_span.b;
   const uword sub_n_cols = col_all ? local_n_cols : in_col2 - in_col1 + 1;
   
-  arma_debug_check
+  arma_debug_check_bounds
     (
     ( row_all ? false : ((in_row1 > in_row2) || (in_row2 >= local_n_rows)) )
     ||
@@ -1194,7 +1193,7 @@ field<oT>::subfield(const span& row_span, const span& col_span, const span& slic
   const uword in_slice2    =                              slice_span.b;
   const uword sub_n_slices = slice_all ? local_n_slices : in_slice2 - in_slice1 + 1;
 
-  arma_debug_check
+  arma_debug_check_bounds
     (
     ( row_all ? false : ((in_row1 > in_row2) || (in_row2 >= local_n_rows)) )
     ||
@@ -1238,7 +1237,7 @@ field<oT>::subfield(const span& row_span, const span& col_span, const span& slic
   const uword in_slice2    =                              slice_span.b;
   const uword sub_n_slices = slice_all ? local_n_slices : in_slice2 - in_slice1 + 1;
 
-  arma_debug_check
+  arma_debug_check_bounds
     (
     ( row_all ? false : ((in_row1 > in_row2) || (in_row2 >= local_n_rows)) )
     ||
@@ -1420,10 +1419,7 @@ field<oT>::for_each(const std::function< void(oT&) >& F)
   {
   arma_extra_debug_sigprint();
   
-  for(uword i=0; i < n_elem; ++i)
-    {
-    F(operator[](i));
-    }
+  for(uword i=0; i < n_elem; ++i)  { F(operator[](i)); }
   
   return *this;
   }
@@ -1437,10 +1433,7 @@ field<oT>::for_each(const std::function< void(const oT&) >& F) const
   {
   arma_extra_debug_sigprint();
   
-  for(uword i=0; i < n_elem; ++i)
-    {
-    F(operator[](i));
-    }
+  for(uword i=0; i < n_elem; ++i)  { F(operator[](i)); }
   
   return *this;
   }
@@ -1457,10 +1450,7 @@ field<oT>::fill(const oT& x)
   
   field<oT>& t = *this;
   
-  for(uword i=0; i<n_elem; ++i)
-    {
-    t[i] = x;
-    }
+  for(uword i=0; i<n_elem; ++i)  { t[i] = x; }
   
   return *this;
   }
@@ -1525,7 +1515,7 @@ field<oT>::in_range(const span& x) const
   {
   arma_extra_debug_sigprint();
   
-  if(x.whole == true)
+  if(x.whole)
     {
     return true;
     }
@@ -1560,7 +1550,7 @@ field<oT>::in_range(const span& row_span, const uword in_col) const
   {
   arma_extra_debug_sigprint();
   
-  if(row_span.whole == true)
+  if(row_span.whole)
     {
     return (in_col < n_cols);
     }
@@ -1583,7 +1573,7 @@ field<oT>::in_range(const uword in_row, const span& col_span) const
   {
   arma_extra_debug_sigprint();
   
-  if(col_span.whole == true)
+  if(col_span.whole)
     {
     return (in_row < n_rows);
     }
@@ -1615,7 +1605,7 @@ field<oT>::in_range(const span& row_span, const span& col_span) const
   const bool rows_ok = row_span.whole ? true : ( (in_row1 <= in_row2) && (in_row2 < n_rows) );
   const bool cols_ok = col_span.whole ? true : ( (in_col1 <= in_col2) && (in_col2 < n_cols) );
   
-  return ( (rows_ok == true) && (cols_ok == true) );
+  return ( rows_ok && cols_ok );
   }
 
 
@@ -1673,7 +1663,7 @@ field<oT>::in_range(const span& row_span, const span& col_span, const span& slic
   const bool   cols_ok =   col_span.whole ? true : ( (in_col1   <= in_col2  ) && (in_col2   < n_cols  ) );
   const bool slices_ok = slice_span.whole ? true : ( (in_slice1 <= in_slice2) && (in_slice2 < n_slices) );
   
-  return ( (rows_ok == true) && (cols_ok == true) && (slices_ok == true) );
+  return ( rows_ok && cols_ok && slices_ok );
   }
 
 
@@ -1709,17 +1699,18 @@ field<oT>::save(const std::string name, const file_type type, const bool print_s
   arma_extra_debug_sigprint();
   
   std::string err_msg;
+  
   const bool save_okay = field_aux::save(*this, name, type, err_msg);
   
-  if( (print_status == true) && (save_okay == false) )
+  if(print_status && (save_okay == false))
     {
     if(err_msg.length() > 0)
       {
-      arma_debug_warn("field::save(): ", err_msg, name);
+      arma_debug_warn("field::save(): ", err_msg, "; file: ", name);
       }
     else
       {
-      arma_debug_warn("field::save(): couldn't write to ", name);
+      arma_debug_warn("field::save(): couldn't write; file: ", name);
       }
     }
   
@@ -1737,17 +1728,18 @@ field<oT>::save(std::ostream& os, const file_type type, const bool print_status)
   arma_extra_debug_sigprint();
   
   std::string err_msg;
+  
   const bool save_okay = field_aux::save(*this, os, type, err_msg);
   
-  if( (print_status == true) && (save_okay == false) )
+  if(print_status && (save_okay == false))
     {
     if(err_msg.length() > 0)
       {
-      arma_debug_warn("field::save(): ", err_msg, "[ostream]");
+      arma_debug_warn("field::save(): ", err_msg);
       }
     else
       {
-      arma_debug_warn("field::save(): couldn't write to [ostream]");
+      arma_debug_warn("field::save(): couldn't write to the given stream");
       }
     }
   
@@ -1765,24 +1757,22 @@ field<oT>::load(const std::string name, const file_type type, const bool print_s
   arma_extra_debug_sigprint();
   
   std::string err_msg;
+  
   const bool load_okay = field_aux::load(*this, name, type, err_msg);
   
-  if( (print_status == true) && (load_okay == false) )
+  if(print_status && (load_okay == false))
     {
     if(err_msg.length() > 0)
       {
-      arma_debug_warn("field::load(): ", err_msg, name);
+      arma_debug_warn("field::load(): ", err_msg, "; file: ", name);
       }
     else
       {
-      arma_debug_warn("field::load(): couldn't read from ", name);
+      arma_debug_warn("field::load(): couldn't read; file: ", name);
       }
     }
   
-  if(load_okay == false)
-    {
-    (*this).reset();
-    }
+  if(load_okay == false)  { (*this).reset(); }
   
   return load_okay;
   }
@@ -1800,22 +1790,19 @@ field<oT>::load(std::istream& is, const file_type type, const bool print_status)
   std::string err_msg;
   const bool load_okay = field_aux::load(*this, is, type, err_msg);
   
-  if( (print_status == true) && (load_okay == false) )
+  if(print_status && (load_okay == false))
     {
     if(err_msg.length() > 0)
       {
-      arma_debug_warn("field::load(): ", err_msg, "[istream]");
+      arma_debug_warn("field::load(): ", err_msg);
       }
     else
       {
-      arma_debug_warn("field::load(): couldn't read from [istream]");
+      arma_debug_warn("field::load(): couldn't read from the given stream");
       }
     }
   
-  if(load_okay == false)
-    {
-    (*this).reset();
-    }
+  if(load_okay == false)  { (*this).reset(); }
   
   return load_okay;
   }
@@ -1961,25 +1948,16 @@ field<oT>::init(const uword n_rows_in, const uword n_cols_in, const uword n_slic
     {
     delete_objects();
     
-    if(n_elem > field_prealloc_n_elem::val)
-      {
-      delete [] mem;
-      }
+    if(n_elem > field_prealloc_n_elem::val)  { delete [] mem; }
     
     if(n_elem_new <= field_prealloc_n_elem::val)
       {
-      if(n_elem_new == 0)
-        {
-        mem = nullptr;
-        }
-      else
-        {
-        mem = mem_local;
-        }
+      mem = (n_elem_new == 0) ? nullptr : mem_local;
       }
     else
       {
       mem = new(std::nothrow) oT* [n_elem_new];
+      
       arma_check_bad_alloc( (mem == nullptr), "field::init(): out of memory" );
       }
     
@@ -2020,10 +1998,7 @@ field<oT>::create_objects()
   {
   arma_extra_debug_sigprint( arma_str::format("n_elem = %d") % n_elem );
   
-  for(uword i=0; i<n_elem; ++i)
-    {
-    mem[i] = new oT;
-    }
+  for(uword i=0; i<n_elem; ++i)  { mem[i] = new oT; }
   }
 
 
@@ -2076,10 +2051,7 @@ inline
 typename field<oT>::iterator&
 field<oT>::iterator::operator--()
   {
-  if(i > 0)
-    {
-    --i;
-    }
+  if(i > 0)  { --i; }
   
   return *this;
   }
@@ -2175,10 +2147,7 @@ inline
 typename field<oT>::const_iterator&
 field<oT>::const_iterator::operator--()
   {
-  if(i > 0)
-    {
-    --i;
-    }
+  if(i > 0)  { --i; }
   
   return *this;
   }
@@ -2343,10 +2312,7 @@ field_aux::reset_objects(field< Mat<eT> >& x)
   {
   arma_extra_debug_sigprint();
   
-  for(uword i=0; i<x.n_elem; ++i)
-    {
-    (*(x.mem[i])).reset();
-    }
+  for(uword i=0; i < x.n_elem; ++i)  { (*(x.mem[i])).reset(); }
   }
 
 
@@ -2358,10 +2324,7 @@ field_aux::reset_objects(field< Col<eT> >& x)
   {
   arma_extra_debug_sigprint();
   
-  for(uword i=0; i<x.n_elem; ++i)
-    {
-    (*(x.mem[i])).reset();
-    }
+  for(uword i=0; i < x.n_elem; ++i)  { (*(x.mem[i])).reset(); }
   }
 
 
@@ -2373,10 +2336,7 @@ field_aux::reset_objects(field< Row<eT> >& x)
   {
   arma_extra_debug_sigprint();
   
-  for(uword i=0; i<x.n_elem; ++i)
-    {
-    (*(x.mem[i])).reset();
-    }
+  for(uword i=0; i < x.n_elem; ++i)  { (*(x.mem[i])).reset(); }
   }
 
 
@@ -2388,10 +2348,7 @@ field_aux::reset_objects(field< Cube<eT> >& x)
   {
   arma_extra_debug_sigprint();
   
-  for(uword i=0; i<x.n_elem; ++i)
-    {
-    (*(x.mem[i])).reset();
-    }
+  for(uword i=0; i < x.n_elem; ++i)  { (*(x.mem[i])).reset(); }
   }
 
 
@@ -2402,10 +2359,7 @@ field_aux::reset_objects(field< std::string >& x)
   {
   arma_extra_debug_sigprint();
   
-  for(uword i=0; i<x.n_elem; ++i)
-    {
-    (*(x.mem[i])).clear();
-    }
+  for(uword i=0; i < x.n_elem; ++i)  { (*(x.mem[i])).clear(); }
   }
 
 
