@@ -32,9 +32,11 @@ svd
   arma_extra_debug_sigprint();
   arma_ignore(junk);
   
-  // it doesn't matter if X is an alias of S, as auxlib::svd() makes a copy of X
+  typedef typename T1::elem_type eT;
   
-  const bool status = auxlib::svd_dc(S, X);
+  Mat<eT> A(X.get_ref());
+  
+  const bool status = auxlib::svd_dc(S, A);
   
   if(status == false)
     {
@@ -60,9 +62,14 @@ svd
   arma_extra_debug_sigprint();
   arma_ignore(junk);
   
-  Col<typename T1::pod_type> out;
+  typedef typename T1::elem_type eT;
+  typedef typename T1::pod_type   T;
   
-  const bool status = auxlib::svd_dc(out, X);
+  Col<T> out;
+  
+  Mat<eT> A(X.get_ref());
+  
+  const bool status = auxlib::svd_dc(out, A);
   
   if(status == false)
     {
@@ -91,6 +98,8 @@ svd
   arma_extra_debug_sigprint();
   arma_ignore(junk);
   
+  typedef typename T1::elem_type eT;
+  
   arma_debug_check
     (
     ( ((void*)(&U) == (void*)(&S)) || (&U == &V) || ((void*)(&S) == (void*)(&V)) ),
@@ -101,8 +110,9 @@ svd
   
   arma_debug_check( ((sig != 's') && (sig != 'd')), "svd(): unknown method specified" );
   
-  // auxlib::svd() makes an internal copy of X
-  const bool status = (sig == 'd') ? auxlib::svd_dc(U, S, V, X) : auxlib::svd(U, S, V, X);
+  Mat<eT> A(X.get_ref());
+  
+  const bool status = (sig == 'd') ? auxlib::svd_dc(U, S, V, A) : auxlib::svd(U, S, V, A);
   
   if(status == false)
     {
@@ -134,6 +144,8 @@ svd_econ
   arma_extra_debug_sigprint();
   arma_ignore(junk);
   
+  typedef typename T1::elem_type eT;
+  
   arma_debug_check
     (
     ( ((void*)(&U) == (void*)(&S)) || (&U == &V) || ((void*)(&S) == (void*)(&V)) ),
@@ -150,14 +162,16 @@ svd_econ
   
   arma_debug_check( ((sig != 's') && (sig != 'd')), "svd_econ(): unknown method specified" );
   
-  const bool status = ((mode == 'b') && (sig == 'd')) ? auxlib::svd_dc_econ(U, S, V, X) : auxlib::svd_econ(U, S, V, X, mode);
+  Mat<eT> A(X.get_ref());
+  
+  const bool status = ((mode == 'b') && (sig == 'd')) ? auxlib::svd_dc_econ(U, S, V, A) : auxlib::svd_econ(U, S, V, A, mode);
   
   if(status == false)
     {
     U.soft_reset();
     S.soft_reset();
     V.soft_reset();
-    arma_debug_warn("svd(): decomposition failed");
+    arma_debug_warn("svd_econ(): decomposition failed");
     }
   
   return status;
